##
##  dnsmasq.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2024 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         dnsmasq
Summary:      DNS Masquerading Daemon
URL:          http://www.thekelleys.org.uk/dnsmasq/doc.html
Vendor:       Simon Kelley
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Networking
License:      GPL
Version:      2.90
Release:      20240214

#   list of sources
Source0:      http://www.thekelleys.org.uk/dnsmasq/dnsmasq-%{version}.tar.xz
Source1:      dnsmasq.conf
Source2:      rc.dnsmasq

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101
PreReq:       OpenPKG, openpkg >= 20160101

%description
    Dnsmasq provides network infrastructure for small networks: DNS,
    DHCP, router advertisement and network boot. It is designed to
    be lightweight and have a small footprint, suitable for resource
    constrained routers and firewalls. It has also been widely used
    for tethering on smartphones and portable hotspots, and to support
    virtual networking in virtualisation frameworks.

%track
    prog dnsmasq = {
        version   = %{version}
        url       = http://www.thekelleys.org.uk/dnsmasq/
        regex     = dnsmasq-(__VER__)\.tar\.xz
    }

%prep
    %setup -q

%build
    #   build program
    defines="-DLEASEFILE=\\\"%{l_prefix}/var/dnsmasq/run/dnsmasq.leases\\\""
    defines="$defines -DRUNFILE=\\\"%{l_prefix}/var/dnsmasq/run/dnsmasq.pid\\\""
    defines="$defines -DCONFFILE=\\\"%{l_prefix}/etc/dnsmasq/dnsmasq.conf\\\""
    %{l_make} %{l_mflags -O} \
        CC="%{l_cc}" \
        CFLAGS="%{l_cflags -O} %{l_cppflags} $defines" \
        LDFLAGS="%{l_ldflags}"

%install
    #   create installation hierarchy
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d \
        $RPM_BUILD_ROOT%{l_prefix}/etc/dnsmasq \
        $RPM_BUILD_ROOT%{l_prefix}/var/dnsmasq/log \
        $RPM_BUILD_ROOT%{l_prefix}/var/dnsmasq/run \
        $RPM_BUILD_ROOT%{l_prefix}/sbin \
        $RPM_BUILD_ROOT%{l_prefix}/man/man8

    #   install program
    %{l_shtool} install -c -s -m 755 \
        src/dnsmasq $RPM_BUILD_ROOT%{l_prefix}/sbin/
    %{l_shtool} install -c -m 644 \
        man/dnsmasq.8 $RPM_BUILD_ROOT%{l_prefix}/man/man8/

    #   install default configuration
    %{l_shtool} install -c -m 644 %{l_value -s -a} \
        %{SOURCE dnsmasq.conf} $RPM_BUILD_ROOT%{l_prefix}/etc/dnsmasq/

    #   install run-command script
    %{l_shtool} install -c -m 755 %{l_value -s -a} \
        %{SOURCE rc.dnsmasq} $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d/

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std} \
        '%config %{l_prefix}/etc/dnsmasq/*' \
        '%attr(-,%{l_rusr},%{l_rgrp}) %{l_prefix}/var/dnsmasq/*'

%files -f files

%clean

%post
    #   after upgrade, restart service
    [ $1 -eq 2 ] || exit 0
    eval `%{l_rc} dnsmasq status 2>/dev/null`
    [ ".$dnsmasq_active" = .yes ] && %{l_rc} dnsmasq restart
    exit 0

%preun
    #   before erase, stop service and remove log files
    [ $1 -eq 0 ] || exit 0
    %{l_rc} dnsmasq stop 2>/dev/null
    rm -f $RPM_INSTALL_PREFIX/var/dnsmasq/log/* >/dev/null 2>&1 || true
    rm -f $RPM_INSTALL_PREFIX/var/dnsmasq/run/* >/dev/null 2>&1 || true
    exit 0

